# About

## Development

Sciline is an open source project by the [European Spallation Source ERIC](https://europeanspallationsource.se/) (ESS).

## License

Sciline is available as open source under the [BSD-3 license](https://opensource.org/licenses/BSD-3-Clause).

## Citing Sciline

Please cite the following:

[![DOI](https://zenodo.org/badge/650569381.svg)](https://zenodo.org/doi/10.5281/zenodo.10301963)

To cite a specific version of Sciline, select the desired version on Zenodo to get the corresponding DOI.

## Older versions of the documentation

Older versions of the documentation pages can be found under the assets of each [release](https://github.com/scipp/sciline/releases).
Simply download the archive, unzip and view locally in a web browser.

## Source code and development

Sciline is hosted and developed [on GitHub](https://github.com/scipp/sciline).
